Option
------

The kind of a Bitwuzla configuration option.

Options are configured via a :class:`bitwuzla.Options` instance,
which must be configured before creating a :class:`bitwuzla.Bitwuzla`
instance.

.. note::

  Some options are labeled as "expert" options. Use with caution.

----

- enum :class:`.Option`

----

.. autoclass:: bitwuzla.Option
   :members:
   :no-index:
   :undoc-members:
